# Number to Thai text

The tool is a convert number to thai text : **Python 3.6+**.

# Features
- Convert number integer or float to Thai text.

# Setup


# Example

```python

from num_thai.thainumbers import NumThai

num = NumThai()
text = num.NumberToTextThai(1111111111111111)

print(text)

```

# About

- Support digit length 1 - 16 digit.
- Support minus digit.
- Support integer or float number.

